<?php defined('_JEXEC') or die('Restricted access');

/**
 * @version 2.0 $Id: ConfUtils.php,v 1.4 2009/11/24 23:25:15 harry Exp $
 * @package Joomla
 * @subpackage H2N Link Directory 2
 * @copyright (C) 2008 - 2009 Harry Klein - www.joomla-hklein.de
 * @Copyright (C) 2006 Soner (pisdoktor) Ekici - www.sonerekici.com
 * @license GNU/GPL, see LICENSE.php
 * 
 * H2N Link Directory 2 is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.
 *
 * H2N Link Directory 2 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EventList; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

require_once(JPATH_COMPONENT_ADMINISTRATOR.DS.'LDConfig.php');


/**
 * Diese Klasse stellt ein paar Methoden bereit, den den Umgang mit 
 * der H2N Link Directory Konfiguration vereinfachen soll. 
 */
class ConfUtils {

	private $_config = null;
	
	/**
	 * Wenn $config nuull ist, wird die Konfiguartion LDConfig benutzt.
	 *
	 * @param LDConfig $config (optional)
	 */
	public function __construct(LDConfig $config = null){
		if ($config == null) {
			$this->_config = new LDConfig();
		}
		else {
			$this->_config = $config;
		}
	}
	
	
	/**
	 * Ermittelt, ob die Suche nach Links aktiviert ist.
	 *
	 * @return true, wenn die Suche nach Links aktiviert ist
	 * @see LDConfig->searchtitle
	 * @see LDConfig->searchurl
	 * @see LDConfig->searchdesc
	 * @see LDConfig->searchlongdesc
	 * @see LDConfig->sengine
	 */
	public function isLinkSearchEnable(){
		$_config = $this->_config ;
		return (bool)(($_config->searchtitle || $_config->searchurl || $_config->searchdesc ||$_config->searchlongdesc) && 	($_config->sengine));
	}

	/**
	 * Ermittelt, ob die Suche nach Kategorien aktiviert ist.
	 *
	 * @return true, wenn die Suche aktiviert ist
	 * @see LDConfig>searchcattitle
	 * @@see LDConfig->searchcatdesc
	 * @@see LDConfig->sengine
	 */
	public function isCategorySearchEnable(){
		$_config = $this->_config ;
		return (bool)(($_config->searchcattitle || ($_config->searchcatdesc)) && $_config->sengine);
	}

	/**
	 * Ermittelt, ob die Suche aktiviert ist
	 *
	 * @return true, wenn Suche aktiviert ist
	 * @see #isLinkSearchEnable()
	 * @see #isCategorySearchEnable()
	 */
	public function isSearchEnable(){
		return (bool)($this->isLinkSearchEnable()|| $this->isCategorySearchEnable());
	}
	
	
	/**
 	* Ermittel aus ldshowdetailpage, showfastlink, 
 	* commentlink und ratelink von LDConfig, ob die Anzeige der Detail-Seite notwendig ist.
 	*
 	* @return true, wenn Detail-Seite angezeigt werden muß
 	*/
	public function needDetailPage(){
		$_config = $this->_config ;
		if ( $_config->ldshowdetailpage || $_config->showfastlink && $_config->commentlink || $_config->ratelink ){
			return true;
		}
		return false;
	}
	
	public function isCommentSystemEnable(){
		$_config = $this->_config ;
		return (boolean) $_config->commentlink;
	}

	public function getCommentSystemType(){
		$_config = $this->_config ;
		if (!$this->isCommentSystemEnable()){
			return false;
		}
		switch ($_config->commentSystem){
			case 'jcomment':
				return 'jcomment';
			case 'intern':
				return 'intern';
			default:
				return false;
		}
	}
}
?>