<?php defined( '_JEXEC' ) or die( 'Restricted access' );

/**
 * @version 2.0 $Id: links.php,v 1.3 2009/12/01 19:50:24 harry Exp $
 * @package Joomla
 * @subpackage H2N Link Directory 2
 * @copyright (C) 2008 - 2009 Harry Klein - www.joomla-hklein.de
 * @Copyright (C) 2006 Soner (pisdoktor) Ekici - www.sonerekici.com
 * @license GNU/GPL, see LICENSE.php
 * 
 * H2N Link Directory 2 is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 2
 * as published by the Free Software Foundation.
 *
 * H2N Link Directory 2 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EventList; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

jimport( 'joomla.application.component.model' );

require_once(JPATH_COMPONENT_ADMINISTRATOR.DS.'LDConfig.php');
require_once(JPATH_COMPONENT.DS.'classes'.DS.'LinkdirectoryURL.php');

class LinkDirectory2ModelLinks extends JModel {

	private $_ld;
	private $_rows_of_links;
	private $_total;
	private $_paginationLinks;
	private $_searchtext;
	
	public function __construct(){
		parent::__construct();
		$this->_ld=new LDConfig();
	}

	public function getSearchResult(){
		$this->_searchtext = JRequest::getString( 'searchtext', 0, 'get' );
		$catid = JRequest::getInt( 'cid', 0, 'get' );
		return $this->search($this->_searchtext,$catid);
	}
	
	public function getSearchText(){
		return $this->_searchtext;
	}

	/**
	 * Suche nach Links. Es wird nach dem Titel der Links gesucht.
	 *
	 * @param string $searchtext Text, nach dem gesucht werden soll
	 * @param int $catid Kategorieid, unterhalb der die Suche erfolgen soll
	 * @return void
	 */
	function search($searchtext, $catid) {
		$db = &JFactory::getDBO();
		$searchtext = $db->getEscaped( trim( strtolower( $searchtext ) ) );
		$limitstart = JRequest::getInt( 'limitstart', 0, 'get' );

		if ($searchtext) {
			$where = array();
			$where[] = '#__ldlinks.published = 1';

			$this->getWhereAllSubCategoriesForLinks($catid,$where);
			$this->getWhereSearchtextForLink($searchtext,$where);
			$this->getWhereForLinksAndPublishCat($where);
			
			$whereAsString = count( $where ) ? "\n WHERE " . implode( ' AND ', $where ) : "" ;
			$this->_total = $this->getTotalCountOfLinkMatches($whereAsString);
			$query = 'SELECT #__ldlinks.* ,#__ldcats.name as category_name FROM #__ldlinks, #__ldcats ' 
			. $whereAsString
			. ' ORDER BY ' . $this->_ld->linkorder
			. " LIMIT $limitstart,". $this->_ld->limitlink ;
			$db->setQuery($query);
			$this->_rows_of_links = $db->loadObjectList();
		} else {
			$this->_rows_of_links=NULL;
			$this->_total = 0;
		}
		return $this->_rows_of_links;

	}
	
	private function getTotalLinks(){
		return $this->_total;
	}
	
	public function &getPageNavigation() {
		if(!$this->_paginationLinks) {
			jimport('joomla.html.pagination');
			global $mainframe;
			$this->_paginationLinks = new JPagination($this->getTotalLinks(), JRequest::getVar('limitstart', 0), 2 /*JRequest::getVar('limit', $mainframe->getCfg('list_limit'))*/);
		}
		return $this->_paginationLinks;
	}
	

	/**
	 * Liefert where-Klausel, um Links in der aktuellen und deren Unterkategorien suchen zu können.
	 *
	 * @param int $catid Katehorie-Id
	 * @param Array mit $where-Klausel, deren Elemente später mit AND verknüpft werden
	 * @global ld->searchonlyinsubcats
	 * @see #getWhereAllSubCategoriesFor
	 *
	 */
	private function getWhereAllSubCategoriesForLinks($catid,&$where){
		$this->getWhereAllSubCategoriesFor($catid,'catid',$where);
	}

	/**
	 * Liefert where-Klausel, um Kategorien in der aktuellen und deren Unterkategorien suchen zu können.
	 *
	 * @param int $catid Katehorie-Id
	 * @param Array mit $where-Klausel, deren Elemente später mit AND verknüpft werden
	 * @global ld->searchonlyinsubcats
	 * @see #getWhereAllSubCategoriesFor
	 *
	 */
	function getWhereAllSubCategoriesForCats($catid,&$where){
		getWhereAllSubCategoriesFor($catid,'id',$where);
	}

	/**
	 * Where-Klausel, um aktuelle und alle deren Unterkategorien zu ermitteln.
	 *
	 * @param int $catid Katehorie-Id
	 * @param $columnName Spaltenname der KategoieId in der Tabelle #__ldlinks bzw. #__ldcats
	 * @param Array mit $where-Klausel, deren Elemente später mit AND verknüpft werden
	 * @global ld->searchonlyinsubcats
	 */
	private function getWhereAllSubCategoriesFor($catid,$columnName,&$where){
		global $database,$my,$ld;
		if ( ( $catid > 0 ) && $ld->searchonlyinsubcats) {
			$whereSubCat[] = "$columnName = $catid";
			getAllSubCategoriesFromCategorie($catid,$columnName,$whereSubCat);

			if (count ($whereSubCat) == 1){
				$where[] = $whereSubCat[0];
			} elseif (count ($whereSubCat) > 1){
				$where[] = '(' . implode( ' OR ', $whereSubCat ) .')';
			}
		}
	}

	/**
	 * Baut die where-Klause bezüglich des Suchtextes für die Suche nach Links zusammen.
	 * Dabei wird berücksichtigt, nach welchen Feldern (title,url,description, long_description) 
	 * eines Links alles gesucht werden soll.
	 *
	 * @param String $searchtext Suchtext
	 * @param array $where where-Klausel
	 * @global $ld->searchtitle
	 * @global $ld->searchurl
	 * @global $ld->searchdesc
	 * @global $ld->searchlongdesc
	 */
	private function getWhereSearchtextForLink($searchtext,&$where){
		if ( $searchtext ) {
			$whereSearch = array();
			if ($this->_ld->searchtitle){
				$whereSearch[] = "LOWER(#__ldlinks.title) LIKE '%$searchtext%'";
			}
			if ($this->_ld->searchurl){
				$whereSearch[] = "LOWER(#__ldlinks.url) LIKE '%$searchtext%'";
			}
			if ($this->_ld->searchdesc){
				$whereSearch[] = "LOWER(#__ldlinks.description) LIKE '%$searchtext%'";
			}
			if ($this->_ld->searchlongdesc){
				$whereSearch[] = "LOWER(#__ldlinks.description_long) LIKE '%$searchtext%'";
			}
			$this->convertWhereArrayToString($whereSearch,'OR',$where);
		}
	}

	private function getWhereForLinksAndPublishCat(&$where){
		$where[] = '#__ldlinks.catid = #__ldcats.id';
		$where[] = '#__ldcats.published = 1';
	}
	
	
	// ===========================================================================
	// = Helper für den Zusammenbau von where-Klauseln                           = 
	// ===========================================================================

	/**
	 * Konvertiert das Array $whereSearch in ein String, indem es die einzelnen Elemente mit $op verknüft.
	 * Das Ergebnis wird dem Array $where hinzugefügt. 
	 *
	 * @param array  $whereSearch
	 * @param String $op AND oder OR
	 * @param array $where (wird verändert)
	 */
	private function convertWhereArrayToString(&$whereSearch,$op,&$where){
		$count=count($whereSearch);
		if ($count > 1) {
			$where[] = '(' . implode( ' '.$op.' ', $whereSearch ) .')';
		}
		elseif ($count == 1) {
			$where[] = $whereSearch[0];
		}
		elseif ($count == 0) {
			// $where[] = '1=0';
		}
	}

	/**
	 * Liefert die Anzahl der Treffer bei der Suche nach Links
	 *
	 * @param string $whereAsString Where-Klausel zum Suchen
	 * @return int Anzahl der Treffer
	 * @global $database
	 */
	function getTotalCountOfLinkMatches($whereAsString ){
		$db = &JFactory::getDBO();
		$query = "SELECT COUNT(*) FROM #__ldlinks, #__ldcats " . $whereAsString ;
		$db->setQuery($query);
		$total = $db->loadResult();
		return $total;
	}
}

?>